/* ver.B.b14.01(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"gpstester",
	"(C) 2000-2007 Hirohisa Mori",
	"ver.B.b14.01(BLAZE)",
	2007,2,27,
	0,
	"gps I/O tester ",
};

